<!doctype html>
<html>
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Mopidy-Local</title>
    <link rel="stylesheet" href="/mopidy/mopidy.css" type="text/css" media="screen, print">
    <style>
      #thumbnails {
        display: grid;
        grid-template-columns: 1fr 1fr 1fr 1fr 1fr 1fr 1fr 1fr;
        grid-gap: 2px;
        line-height: 0%;
      }
      #thumbnails a {
        border: none;
      }
      #thumbnails img {
        border: none;
        width: 100%;
        aspect-ratio: 1;
      }
    </style>
  </head>
  <body>
    <div class="box focus">
      <h1>Mopidy-Local</h1>
      <p>
        This Web client is used to serve album art extracted from local
        media files by the Mopidy-Local extension.
      </p>
    </div>
    <div class="box">
      <h2>Image cache</h2>
      <p>Images extracted from local media files will automatically appear
      here.</p>
      <div id="thumbnails">
        {% for image in images %}
          <a href="{{image}}">
            <img src="{{image}}" alt="Album art thumbnail" loading="lazy">
          </a>
        {% end %}
      </div>
    </div>
  </body>
</html>
